@@ -101,7 +101,7 @@ void TestGData::dumpPost(const BlogPost *post)
     qDebug() << "# title: " << post->title();
     qDebug() << "# content: " << post->content();
     qDebug() << "# private: " << post->isPrivate();
-    qDebug() << "# categories: " << post->categories().join(QLatin1String(" "));
+    qDebug() << "# categories: " << post->categories().join(QLatin1Char(' '));
     qDebug() << "# error: " << post->error();
     qDebug() << "# journalId: " << post->journalId();
     switch (post->status()) {
